@@ -1,12 +1,13 @@
 
 splittingEdge <- function(g)
 {
-   n <- Order(g)
-	s <- Size(g)
+   n <- vcount(g)
+	s <- ecount(g)
+	edges <- get.edgelist(g)+1
 
 	retval <- .C("SplittingEdge",
-					 edges1 = as.integer(g[,1]),
-					 edges2 = as.integer(g[,2]),
+					 edges1 = as.integer(edges[,1]),
+					 edges2 = as.integer(edges[,2]),
 					 N = as.integer(n),
 					 S = as.integer(s),
 					 edge = integer(1),
@@ -16,13 +17,14 @@ splittingEdge <- function(g)
 
 splittingEdges <- function(g)
 {
-   n <- Order(g)
-	s <- Size(g)
+   n <- vcount(g)
+	s <- ecount(g)
 	if(s==0) return(rep(0,n))
+	edges <- get.edgelist(g)+1
 
 	retval <- .C("SplittingEdges",
-					 edges1 = as.integer(g[,1]),
-					 edges2 = as.integer(g[,2]),
+					 edges1 = as.integer(edges[,1]),
+					 edges2 = as.integer(edges[,2]),
 					 N = as.integer(n),
 					 S = as.integer(s),
 					 splitting = integer(s),
